#ifndef HEADER_HASH
#define HEADER_HASH

#include "config.h"
#include "tcltk.h"
#include <stdlib.h>
#include <strings.h>

typedef Tcl_HashTable hash;

void hash_create(hash *table);
void hash_destroy(hash *table);
int hash_set(hash *table, const char *key, const char *value);
char *hash_get(hash *table, const char *key);
int hash_delete(hash *table, char *key);

#endif
